<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://pampa.dev
 * @since      1.0.0
 *
 * @package    Auto_Translate
 * @subpackage Auto_Translate/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Auto_Translate
 * @subpackage Auto_Translate/admin
 * @author     Pampa Dev <intouch@pampa.dev>
 */
class Auto_Translate_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Auto_Translate_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Auto_Translate_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/auto-translate-admin.min.css', array(), $this->version, 'all' );
		wp_enqueue_style( 'wp-color-picker' );
	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Auto_Translate_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Auto_Translate_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/auto-translate-admin.min.js', array( 'jquery','wp-color-picker' ), $this->version, false );

	}

	public function create_admin_menu() {
		//create new top-level menu
		add_menu_page(__('Auto Translate Settings', 'auto-translate'), __('Auto Translate', 'auto-translate'), 'administrator', 'auto_translate', array($this, 'auto_translate_settings_page'), 'dashicons-translation', 98);
	}

	function plugin_settings() {
		//register our settings
		register_setting( 'auto-translate-language-settings-group', 'wpat_base_language' );
		register_setting( 'auto-translate-language-settings-group', 'wpat_supported_languages' , array('type'=>'array'));
		register_setting( 'auto-translate-visual-settings-group', 'wpat_button_icon' );
		register_setting( 'auto-translate-visual-settings-group', 'wpat_color_1' );
		register_setting( 'auto-translate-visual-settings-group', 'wpat_color_2' );
		register_setting( 'auto-translate-visual-settings-group', 'wpat_size' );
		register_setting( 'auto-translate-visual-settings-group', 'wpat_border_radius' );
		register_setting( 'auto-translate-visual-settings-group', 'wpat_border_thickness' );
		register_setting( 'auto-translate-visual-settings-group', 'wpat_border_color' );
		register_setting( 'auto-translate-visual-settings-group', 'wpat_font_color' );
		register_setting( 'auto-translate-visual-settings-group', 'wpat_default_location', [ 'type '=> 'boolean', 'default' => true]);
	}

	public function auto_translate_settings_page(){
		global $supported_languages;
		$langs_per_column = 27;
		$vars = [];
		$vars['active_tab'] = isset( $_GET[ 'tab' ] ) ? $_GET[ 'tab' ] : 'language_settings';
		$vars['tabs'] = [
			'language_setting' => [
				'supported_languages' => $supported_languages,
				'count' => 1,
				'langs_per_column' => $langs_per_column,
				'columns' => ceil(sizeof($supported_languages) / $langs_per_column),
				'wpat_supported_languages' => get_option('wpat_supported_languages'),
				'wpat_base_language' => get_option('wpat_base_language')
			],
			'visual_settings' => [
				'wpat_size' => get_option('wpat_size'),
				'wpat_color_1' => get_option('wpat_color_1'),
				'wpat_color_2' => get_option('wpat_color_2'),
				'wpat_border_radius' => get_option('wpat_border_radius'),
				'wpat_border_thickness' => get_option('wpat_border_thickness'),
				'wpat_border_color' => get_option('wpat_border_color'),
				'wpat_button_icon' => get_option('wpat_button_icon'),
				'wpat_font_color' => get_option('wpat_font_color'),
				'wpat_default_location' => get_option('wpat_default_location', true),
				'columns' => 1
			]
		];
		require_once 'partials/auto-translate-admin-display.php';
	}
}
